@@ -134,7 +134,7 @@ class TestPhenixPdbCif(TestImportData):
             self.assertAlmostEqual(protMolProbity.ramachandranFavored.get(),
                                    ramFavored, delta=delta)
             self.assertAlmostEqual(protMolProbity.rotamerOutliers.get(),
-                                   rotOutliers, delta=delta)
+                                   rotOutliers, delta=3)
             self.assertAlmostEqual(protMolProbity.cbetaOutliers.get(),
                                    cbetaOutliers, delta=delta)
             self.assertAlmostEqual(protMolProbity.clashscore.get(),
@@ -183,7 +183,7 @@ class TestPhenixPdbCif(TestImportData):
                                    ramFavored, delta=1)
             print("Checking rotOutliers")
             self.assertAlmostEqual(protValCryoEM.rotamerOutliers.get(),
-                                   rotOutliers, delta=3)
+                                   rotOutliers, delta=4)
             print("Checking cbetaOutliers")
             self.assertAlmostEqual(protValCryoEM.cbetaOutliers.get(),
                                    cbetaOutliers, places)
@@ -268,7 +268,8 @@ class TestPhenixPdbCif(TestImportData):
         protChimera = self.newProtocol(ChimeraProtOperate, **args)
         protChimera.setObjLabel('chimera operate\n repairing CIF\n')
         self.launchProtocol(protChimera)
-        result = protChimera.repaired_CIF_ChimeraX_Atom_struct__2_000090
+        result = eval("protChimera.repaired_CIF_ChimeraX_Atom_struct__2_%06d" % \
+                 protChimera.getObjId())
 
         # EMRinger
         args = {'inputVolume': volume_hemo_orig,
@@ -499,8 +500,8 @@ class TestPhenixPdbCif(TestImportData):
         protChimera = self.newProtocol(ChimeraProtOperate, **args)
         protChimera.setObjLabel('chimera operate\n repairing CIF\n')
         self.launchProtocol(protChimera)
-        result = protChimera.repaired_CIF_ChimeraX_Atom_struct__2_000772
-
+        result = eval("protChimera.repaired_CIF_ChimeraX_Atom_struct__2_%06d" % \
+                 protChimera.getObjId())
         # MolProbity
         args = {
                 'inputVolume': volume_hemo_org,
@@ -667,7 +668,8 @@ class TestPhenixPdbCif(TestImportData):
         protChimera = self.newProtocol(ChimeraProtOperate, **args)
         protChimera.setObjLabel('chimera operate\n repairing CIF\n')
         self.launchProtocol(protChimera)
-        result = protChimera.repaired_CIF_ChimeraX_Atom_struct__2_001077
+        result = eval("protChimera.repaired_CIF_ChimeraX_Atom_struct__2_%06d" % \
+                 protChimera.getObjId())
 
         # MolProbity
         args = {
